From 1d1aa7a02fc64286a0c81cfb40fbf16f704d017e Mon Sep 17 00:00:00 2001
From: ZuBsPaCe <kurt.rudin@gmx.net>
Date: Fri, 10 Sep 2021 22:08:02 +0200
Subject: GDScript: Removed spurious UNASSIGNED_VARIABLE warning for locals

Variable->assignment needs to be incremented when assigned a value.
Also fixed and improved unit test 'variable_declaration.gd'.
Fixes #52551
---
 .../scripts/parser/features/variable_declaration.gd | 21 ++++++++++++++-------
 .../parser/features/variable_declaration.out        |  6 +-----
 2 files changed, 15 insertions(+), 12 deletions(-)

(limited to 'modules/gdscript/tests/scripts/parser/features')

diff --git a/modules/gdscript/tests/scripts/parser/features/variable_declaration.out b/modules/gdscript/tests/scripts/parser/features/variable_declaration.out
index 2e0a63c024..7817dd3169 100644
--- a/modules/gdscript/tests/scripts/parser/features/variable_declaration.out
+++ b/modules/gdscript/tests/scripts/parser/features/variable_declaration.out
@@ -1,7 +1,3 @@
 GDTEST_OK
->> WARNING
->> Line: 5
->> UNASSIGNED_VARIABLE
->> The variable 'c' was used but never assigned a value.
-1 42 2 23
+11 22 33 44 55 66 77 88
 OK
diff --git a/modules/gdscript/tests/scripts/parser/features/variable_declaration.gd b/modules/gdscript/tests/scripts/parser/features/variable_declaration.gd
index 3b48f10ca7..38567d35c6 100644
--- a/modules/gdscript/tests/scripts/parser/features/variable_declaration.gd
+++ b/modules/gdscript/tests/scripts/parser/features/variable_declaration.gd
@@ -1,12 +1,19 @@
-var a # No init.
-var b = 42 # Init.
+var m1 # No init.
+var m2 = 22 # Init.
+var m3: String # No init, typed.
+var m4: String = "44" # Init, typed.
 
 func test():
-	var c # No init, local.
-	var d = 23 # Init, local.
+	var loc5 # No init, local.
+	var loc6 = 66 # Init, local.
+	var loc7: String # No init, typed.
+	var loc8: String = "88" # Init, typed.
 
-	a = 1
-	c = 2
+	m1 = 11
+	m3 = "33"
 
-	prints(a, b, c, d)
+	loc5 = 55
+	loc7 = "77"
+
+	prints(m1, m2, m3, m4, loc5, loc6, loc7, loc8)
 	print("OK")
-- 
cgit v1.2.3